@@ -2,11 +2,11 @@ loglikelihood.zigp.full <-
 function (delta)
 {
     n <- get("n", pos=globalenv())
-    k <- get("k", pos=globalenv())
+    k <- get("ksave", pos=globalenv())
+    Ysave <- get("Ysave", pos=globalenv())
     Xsave <- get("Xsave", pos=globalenv())
     Wsave <- get("Wsave", pos=globalenv())
     Zsave <- get("Zsave", pos=globalenv())
-    Y <- get("Y", pos=globalenv())
     t.i <- get("t.i", pos=globalenv())
 
     eta <- double(n)
@@ -28,12 +28,12 @@ function (delta)
     else { omega <- 0 }
 
     if (omega>0) {
-      s1 <- sum(ifelse(Y == 0, 1, 0) * log(omega + (1 - omega) *
+      s1 <- sum(ifelse(Ysave == 0, 1, 0) * log(omega + (1 - omega) *
             exp(-t.i * exp(eta)/phi))) }
-    else { s1 <- sum(ifelse(Y == 0, 1, 0) * (-t.i * exp(eta)/phi)) }
-    s2 <- sum(ifelse(Y > 0, 1, 0) * (log(1 - omega) + log(t.i) +
-        eta + (Y - 1) * log(t.i * exp(eta) + (phi - 1) * Y) -
-        Y * log(phi) - (t.i * exp(eta) + (phi - 1) * Y)/phi- lgamma(Y + 1)))
+    else { s1 <- sum(ifelse(Ysave == 0, 1, 0) * (-t.i * exp(eta)/phi)) }
+    s2 <- sum(ifelse(Ysave > 0, 1, 0) * (log(1 - omega) + log(t.i) +
+        eta + (Ysave - 1) * log(t.i * exp(eta) + (phi - 1) * Ysave) -
+        Ysave * log(phi) - (t.i * exp(eta) + (phi - 1) * Ysave)/phi- lgamma(Ysave + 1)))
     l <- s1 + s2
     return(-l)
 }
